---
title: "gke/WARN/2022_007"
linkTitle: "WARN/2022_007"
weight: 1
type: docs
description: >
  GKE nodes need Storage API access scope to retrieve build artifacts
---

**Product**: [Google Kubernetes Engine](https://cloud.google.com/kubernetes-engine)\
**Rule class**: WARN - Something that is possibly wrong

### Description

GKE nodes must have `storage.googleapis.com` API access scope to retrieve build artifacts.
These artifacts can be binaries/configs for node bootstrapping process or images from private Container or Artifact Registry repositories. Nodes may report connection timeouts during node bootstrapping or `401 Unauthorized` if they cannot pull from a private repositories.

### Remediation

The [best practice](https://cloud.google.com/compute/docs/access/service-accounts#scopes_best_practice) when it comes to access scopes is to set the `cloud-platform` access scope and then control the service account's access by granting it IAM roles. Alternatively, use the `gke-default` alias when creating node pools or clusters to provide all the [scopes required for GKE](https://cloud.google.com/sdk/gcloud/reference/container/clusters/create#--scopes) to run smoothly.

### Further information

- [Cannot pull images from private container registry repository](https://cloud.google.com/kubernetes-engine/docs/troubleshooting#401_unauthorized_cannot_pull_images_from_private_container_registry_repository)
- [Storage API Scopes](https://cloud.google.com/storage/docs/authentication#oauth-scopes)
- [Access required for Artifact Registry](https://cloud.google.com/artifact-registry/docs/access-control#gcp)
- [Access required for Container Registry](https://cloud.google.com/container-registry/docs/access-control#gce)
